pub type FieldList = Vec<(Token, Option<Expression>, Expression)>;Expand description
An ordered list of Name = Value pairs.
This is usually used as the body of a tuple in the UCG AST.
Aliased Type
pub struct FieldList { /* private fields */ }pub type FieldList = Vec<(Token, Option<Expression>, Expression)>;An ordered list of Name = Value pairs.
This is usually used as the body of a tuple in the UCG AST.
pub struct FieldList { /* private fields */ }