Module ucglib::convert [−][src]
The conversion stage of the ucg compiler.
Modules
| env |
Contains code for converting a UCG Val into the environment variable output target. |
| exec |
Contains code for converting a UCG Val into an executable script output target. |
| flags |
Contains code for converting a UCG Val into the command line flag output target. |
| json |
Flags contains code for converting a UCG Val into the json output target. |
| traits |
The traits used by the ucg compiler for converting Val intermediate format into the output formats.. |
| yaml |
Structs
| ConverterRegistry |
ConverterRunner knows how to run a given converter on a Val. |